pub enum PropsUpdateMode {
Set = 0,
Merge = 1,
Replace = 2,
}Expand description
The mode of a Props update operation, used in various commands.
Variants
Set = 0
Replace the entire property list with the new one.
Merge = 1
Merge the new property list with the current one without overwriting any values.
Replace = 2
Merge the new property list with the current one, overwriting any values.