Props

Struct Props 

pub struct Props(/* private fields */);
A list of key-value pairs that associate arbitrary properties with an object. Keys are null-terminated strings and values are arbitrary binary blobs, although by convention both are usually null-terminated ASCII strings.

Implementations

Source

impl Props

pub fn new() -> Self

Creates a new, empty property list.

pub fn set<T>(&mut self, prop: Prop, value: T)
where T: AsRef<CStr>,

Sets a well-known property in the map.

If the property already has a value, it will be overwritten with the new one.

pub fn set_bytes<K, V>(&mut self, key: K, value: V)
where K: AsRef<CStr>, V: AsRef<[u8]>,

Sets a a property in the map.

If the property already has a value, it will be overwritten with the new one.

pub fn get(&self, prop: Prop) -> Option<&[u8]>

Gets the value of a well-known property.

If prop is not in the map, returns None.

pub fn get_mut(&mut self, prop: Prop) -> Option<&mut [u8]>

Gets the value of a well-known property.

If prop is not in the map, returns None.

pub fn get_bytes<K>(&self, key: K) -> Option<&[u8]>
where K: AsRef<CStr>,

Gets a property from the map.

pub fn get_bytes_mut<K>(&mut self, key: K) -> Option<&mut [u8]>
where K: AsRef<CStr>,

s Get a property from the map.

pub fn iter(&self) -> Iter<'_, Box<CStr>, Box<[u8]>>

Create an Iterator over the properties.