pub struct RecordBuffer { /* private fields */ }Expand description
A buffer for adapting a record stream in situations where an implementation of AsyncRead is required.
Implementations
Sourceimpl RecordBuffer
impl RecordBuffer
Sourcepub fn new(capacity: usize) -> Self
pub fn new(capacity: usize) -> Self
Create a new record buffer with the given capacity. If you created the
record stream with a specific set of
Buffer Attributes, the capacity should be at
least equal to the max_length parameter. Alternatively, just pick
something reasonably large.
Sourceimpl RecordBuffer
impl RecordBuffer
Sourcepub fn as_record_sink(&self) -> impl RecordSink
pub fn as_record_sink(&self) -> impl RecordSink
Creates a type suitable for use as a RecordSink when creating a new [RecordStream].