pub struct RecordStream(/* private fields */);Expand description
A stream of audio data sent from the server to the client, originating from a source.
The stream handle can be freely cloned and shared between threads.
Implementations
Sourceimpl RecordStream
impl RecordStream
Sourcepub fn buffer_attr(&self) -> &BufferAttr
pub fn buffer_attr(&self) -> &BufferAttr
The attributes of the server-side buffer.
Sourcepub fn sample_spec(&self) -> &SampleSpec
pub fn sample_spec(&self) -> &SampleSpec
The sample specification for the stream. Can differ from the client’s requested sample spec.
Sourcepub fn channel_map(&self) -> &ChannelMap
pub fn channel_map(&self) -> &ChannelMap
The channel map for the stream.
Sourcepub async fn set_name(&self, name: CString) -> ClientResult<()>
pub async fn set_name(&self, name: CString) -> ClientResult<()>
Sets the name of the record stream.
Sourcepub async fn timing_info(&self) -> ClientResult<RecordLatency>
pub async fn timing_info(&self) -> ClientResult<RecordLatency>
Fetches record timing information for the record stream.
Sourcepub async fn cork(&self) -> ClientResult<()>
pub async fn cork(&self) -> ClientResult<()>
Corks the record stream (temporarily pausing recording).
Sourcepub async fn uncork(&self) -> ClientResult<()>
pub async fn uncork(&self) -> ClientResult<()>
Uncorks the record stream.
Sourcepub async fn started(&self) -> ClientResult<()>
pub async fn started(&self) -> ClientResult<()>
Returns a future that resolves when the first bytes are written to the stream by the server.
Sourcepub async fn delete(self) -> ClientResult<()>
pub async fn delete(self) -> ClientResult<()>
Deletes the stream from the server.