A pure Rust implementation of the PulseAudio protocol, suitable for writing servers and clients.
Modules
- protocol
- An implementation of the PulseAudio IPC protocol.
Structs
- Client
- A PulseAudio client.
- Playback
Stream - A stream of audio data sent from the client to the server for playback in a sink.
- Record
Buffer - A buffer for adapting a record stream in situations where an implementation of AsyncRead is required.
- Record
Stream - A stream of audio data sent from the server to the client, originating from a source.
Enums
- Client
Error - An error encountered by a Client.
Traits
- AsPlayback
Source - A trait for converting a callback into an [AudioSource].
- Playback
Source - An audio source for a playback stream. At its core, this is just a callback that is driven by the server to generate samples.
- Record
Sink - An audio sink for a record stream. At its core, this is just a callback that is called whenever the server sends samples for the stream.
Functions
- cookie_
path_ from_ env - Attempts to find the authentication cookie from the environment, checking the following locations in order:
- socket_
path_ from_ env - Attempts to determine the socket path from the runtime environment, checking the following locations in order: